@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::Author::ETHER;
 {
-  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.009';
+  $Dist::Zilla::PluginBundle::Author::ETHER::VERSION = '0.010';
 }
-# git description: v0.008-6-g0bfc26e
+# git description: v0.009-11-g611096b
 
 BEGIN {
   $Dist::Zilla::PluginBundle::Author::ETHER::AUTHORITY = 'cpan:ETHER';
@@ -55,15 +55,17 @@ sub configure
         # Gather Files
         [ 'Git::GatherDir'      => { exclude_filename => 'LICENSE' } ],
         qw(MetaYAML MetaJSON License Readme Manifest),
-        [ 'Test::Compile'       => { fail_on_warning => 1, bail_out_on_fail => 1 } ],
-        [ 'Test::CheckDeps'     => { fatal => 1 } ],
+        [ 'Test::Compile'       => { ':version' => '2.002', fail_on_warning => 1, bail_out_on_fail => 1 } ],
+        [ 'Test::CheckDeps'     => { ':version' => '0.007', fatal => 1, level => 'suggests' } ],
+
         'NoTabsTests',
         'EOLTests',
         'MetaTests',
         'Test::Version',
-        'Test::CPAN::Changes',
+        [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
         'Test::ChangesHasContent',
-        [ 'Test::MinimumVersion' => { max_target_perl => '5.008008' } ],
+        'Test::UnusedVars',
+        [ 'Test::MinimumVersion' => { ':version' => '2.0000003', max_target_perl => '5.008008' } ],
         'PodSyntaxTests',
         'PodCoverageTests',
         'Test::PodSpelling',
@@ -81,13 +83,15 @@ sub configure
         'PkgVersion',
         'PodWeaver',
         #[%PodWeaver]
-        [ 'NextRelease'         => { format => '%-8V  %{yyyy-MM-dd HH:mm:ss ZZZZ}d (%U)' } ],
+        [ 'NextRelease'         => { ':version' => '4.300018', format => '%-8V  %{yyyy-MM-dd HH:mm:ss ZZZZ}d (%U)' } ],
 
         # Register Prereqs
         # (MakeMaker or other installer)
         'AutoPrereqs',
         'MinimumPerl',
-        [ 'Prereqs'             => {
+        [ 'Prereqs' => installer_requirements => {
+                # this is mostly pointless as by the time this runs, we're
+                # already trying to load the installer plugin
                 '-phase' => 'develop', '-relationship' => 'requires',
                 'Dist::Zilla' => Dist::Zilla->VERSION,
                 blessed($self) => $self->VERSION,
@@ -148,7 +152,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -205,15 +209,16 @@ following C<dist.ini> (following the preamble):
     bail_out_on_fail = 1
 
     [Test::CheckDeps]
-    :version = 0.005
+    :version = 0.007
     fatal = 1
+    level = suggests
 
     [NoTabsTests]
     [EOLTests]
     [MetaTests]
+    [Test::Version]
     [Test::CPAN::Changes]
     [Test::ChangesHasContent]
-    [Test::Version]
     [Test::UnusedVars]
 
     [Test::MinimumVersion]
@@ -223,6 +228,7 @@ following C<dist.ini> (following the preamble):
     [PodSyntaxTests]
     [PodCoverageTests]
     [Test::PodSpelling]
+    ;[Test::Pod::LinkCheck]     many outstanding bugs
     [Test::Pod::No404s]
 
 
